"use strict";
var _ = require("underscore");
var CheckboxValueConverter = (function () {
    function CheckboxValueConverter(trueValue, falseValue) {
        this.trueValue = trueValue;
        this.falseValue = falseValue;
    }
    CheckboxValueConverter.prototype.convert = function (data) {
        return data === this.trueValue;
    };
    CheckboxValueConverter.prototype.convertBack = function (value) {
        if (value) {
            return this.trueValue;
        }
        return this.falseValue;
    };
    return CheckboxValueConverter;
}());
exports.CheckboxValueConverter = CheckboxValueConverter;
var IdEntityValueConverter = (function () {
    function IdEntityValueConverter(convertBack) {
        this.convertBack = convertBack;
    }
    IdEntityValueConverter.prototype.convert = function (data) {
        return !data ? "0" : data.id;
    };
    return IdEntityValueConverter;
}());
exports.IdEntityValueConverter = IdEntityValueConverter;
var IdValueConverter = (function () {
    function IdValueConverter(convertBack) {
        this.convertBack = convertBack;
    }
    IdValueConverter.prototype.convert = function (data) {
        return data;
    };
    return IdValueConverter;
}());
exports.IdValueConverter = IdValueConverter;
var NumericIdEntityValueConverter = (function () {
    function NumericIdEntityValueConverter(convertBack) {
        this.convertBack = convertBack;
    }
    NumericIdEntityValueConverter.prototype.convert = function (data) {
        return !data || _.isUndefined(data) || _.isNull(data) ? "0" : data.id.toString();
    };
    return NumericIdEntityValueConverter;
}());
exports.NumericIdEntityValueConverter = NumericIdEntityValueConverter;
var NumericIdValueConverter = (function () {
    function NumericIdValueConverter(convertBack) {
        this.convertBack = convertBack;
    }
    NumericIdValueConverter.prototype.convert = function (data) {
        return _.isUndefined(data) || _.isNull(data) ? "0" : data.toString();
    };
    return NumericIdValueConverter;
}());
exports.NumericIdValueConverter = NumericIdValueConverter;
var DefaultValueConverter = (function () {
    function DefaultValueConverter() {
    }
    DefaultValueConverter.prototype.convert = function (data) {
        return data;
    };
    DefaultValueConverter.prototype.convertBack = function (value) {
        return value;
    };
    DefaultValueConverter.instance = new DefaultValueConverter();
    return DefaultValueConverter;
}());
exports.DefaultValueConverter = DefaultValueConverter;
var NumericValueConverter = (function () {
    function NumericValueConverter(options) {
        this.options = options;
    }
    NumericValueConverter.prototype.convert = function (data) {
        var decimals = this.options && this.options.decimals;
        return _.isUndefined(data) || _.isNull(data) ? null : data.toFixed(decimals);
    };
    NumericValueConverter.prototype.convertBack = function (value) {
        try {
            console.log("value", value);
            if (!value.length) {
                return null;
            }
            if (value.length === 1 && value === "-") {
                return 0;
            }
            if (value.length === 2 && value === "-.") {
                return 0;
            }
            var decimals = this.options && this.options.decimals;
            var v = decimals ? parseFloat(value) : parseInt(value);
            if (isNaN(v)) {
                return;
            }
            if (this.options) {
                if (!_.isUndefined(this.options.max)) {
                    if (v > this.options.max) {
                        v = this.options.max;
                    }
                }
                if (!_.isUndefined(this.options.min)) {
                    if (v < this.options.min) {
                        v = this.options.min;
                    }
                }
            }
            if (decimals) {
                return parseFloat(v.toFixed(decimals));
            }
            return v;
        }
        catch (e) {
        }
    };
    return NumericValueConverter;
}());
exports.NumericValueConverter = NumericValueConverter;
